@@ -6,7 +6,7 @@ from .constants import *  # noqa: F403
 from .exceptions import *  # noqa: F403
 from .mechanisms import *  # noqa: F403
 from .types import *  # noqa: F403
-
+from .util import dh, dsa, ec, rsa, x509  # noqa: F401
 
 _so = None
 _lib = None
@@ -23,7 +23,8 @@ def lib(so):
     if _lib:
         if _so != so:
             raise AlreadyInitialized(  # noqa: F405
-                "Already initialized with %s" % so)
+                "Already initialized with %s" % _so
+            )
         else:
             return _lib
 
