@@ -10,6 +10,7 @@ class KeyType(IntEnum):
 
     Key types beginning with an underscore are historic and are best avoided.
     """
+
     RSA = 0x00000000
     """
     See the `RSA section
@@ -90,6 +91,10 @@ class KeyType(IntEnum):
     SHA384_HMAC = 0x0000002C
     SHA512_HMAC = 0x0000002D
     SHA224_HMAC = 0x0000002E
+    SHA3_224_HMAC = 0x00000036
+    SHA3_256_HMAC = 0x00000037
+    SHA3_384_HMAC = 0x00000038
+    SHA3_512_HMAC = 0x00000039
     SEED = 0x0000002F
     GOSTR3410 = 0x00000030
     GOSTR3411 = 0x00000031
@@ -101,7 +106,7 @@ class KeyType(IntEnum):
     _VENDOR_DEFINED = 0x80000000
 
     def __repr__(self):
-        return '<KeyType.%s>' % self.name
+        return "<KeyType.%s>" % self.name
 
 
 class Mechanism(IntEnum):
@@ -191,6 +196,10 @@ class Mechanism(IntEnum):
     """
     .. note:: Default for signing/verification with :attr:`KeyType.RSA` keys.
     """
+    SHA3_224_RSA_PKCS = 0x00000066
+    SHA3_256_RSA_PKCS = 0x00000060
+    SHA3_384_RSA_PKCS = 0x00000061
+    SHA3_512_RSA_PKCS = 0x00000062
 
     RSA_PKCS_PSS = 0x0000000D
     """
@@ -213,6 +222,10 @@ class Mechanism(IntEnum):
     SHA256_RSA_PKCS_PSS = 0x00000043
     SHA384_RSA_PKCS_PSS = 0x00000044
     SHA512_RSA_PKCS_PSS = 0x00000045
+    SHA3_256_RSA_PKCS_PSS = 0x00000063
+    SHA3_384_RSA_PKCS_PSS = 0x00000064
+    SHA3_512_RSA_PKCS_PSS = 0x00000065
+    SHA3_224_RSA_PKCS_PSS = 0x00000067
 
     RSA_X9_31_KEY_PAIR_GEN = 0x0000000A
     RSA_X9_31 = 0x0000000B
@@ -462,6 +475,13 @@ class Mechanism(IntEnum):
     SHA512_KEY_DERIVATION = 0x00000395
     SHA224_KEY_DERIVATION = 0x00000396
 
+    SHA3_256_KEY_DERIVATION = 0x00000397
+    SHA3_224_KEY_DERIVATION = 0x00000398
+    SHA3_384_KEY_DERIVATION = 0x00000399
+    SHA3_512_KEY_DERIVATION = 0x0000039A
+    SHAKE_128_KEY_DERIVATION = 0x0000039B
+    SHAKE_256_KEY_DERIVATION = 0x0000039C
+
     _PBE_MD2_DES_CBC = 0x000003A0
     _PBE_MD5_DES_CBC = 0x000003A1
     _PBE_MD5_CAST_CBC = 0x000003A2
@@ -538,7 +558,7 @@ class Mechanism(IntEnum):
     _SKIPJACK_CFB8 = 0x00001007
     _SKIPJACK_WRAP = 0x00001008
     _SKIPJACK_PRIVATE_WRAP = 0x00001009
-    _SKIPJACK_RELAYX = 0x0000100a
+    _SKIPJACK_RELAYX = 0x0000100A
 
     _KEA_KEY_PAIR_GEN = 0x00001010
     _KEA_KEY_DERIVE = 0x00001011
@@ -659,6 +679,10 @@ class Mechanism(IntEnum):
     AES_CFB1 = 0x00002108
     AES_KEY_WRAP = 0x00002109
     AES_KEY_WRAP_PAD = 0x0000210A
+    AES_KEY_WRAP_KWP = 0x0000210B
+    """Bug: SoftHSMv2 mechanism AES_KEY_WRAP_PAD is actually AES_KEY_WRAP_KWP"""
+    AES_KEY_WRAP_PKCS7 = 0x0000210C
+    """PKCS #11 v3.1: AES_KEY_WRAP_PAD is deprecated due to confusion in implementation"""
 
     DES_ECB_ENCRYPT_DATA = 0x00001100
     DES_CBC_ENCRYPT_DATA = 0x00001101
@@ -706,16 +730,34 @@ class Mechanism(IntEnum):
     EDDSA = 0x00001057
     EC_EDWARDS_KEY_PAIR_GEN = 0x00001055
 
+    SHA3_256 = 0x000002B0
+    SHA3_256_HMAC = 0x000002B1
+    SHA3_256_HMAC_GENERAL = 0x000002B2
+    SHA3_256_KEY_GEN = 0x000002B3
+    SHA3_224 = 0x000002B5
+    SHA3_224_HMAC = 0x000002B6
+    SHA3_224_HMAC_GENERAL = 0x000002B7
+    SHA3_224_KEY_GEN = 0x000002B8
+    SHA3_384 = 0x000002C0
+    SHA3_384_HMAC = 0x000002C1
+    SHA3_384_HMAC_GENERAL = 0x000002C2
+    SHA3_384_KEY_GEN = 0x000002C3
+    SHA3_512 = 0x000002D0
+    SHA3_512_HMAC = 0x000002D1
+    SHA3_512_HMAC_GENERAL = 0x000002D2
+    SHA3_512_KEY_GEN = 0x000002D3
+
     _VENDOR_DEFINED = 0x80000000
 
     def __repr__(self):
-        return '<Mechanism.%s>' % self.name
+        return "<Mechanism.%s>" % self.name
 
 
 class KDF(IntEnum):
     """
     Key Derivation Functions.
     """
+
     NULL = 0x00000001
     SHA1 = 0x00000002
 
@@ -726,20 +768,29 @@ class KDF(IntEnum):
     SHA384 = 0x00000007
     SHA512 = 0x00000008
     CPDIVERSIFY = 0x00000009
+    SHA3_224_KDF = 0x0000000A
+    SHA3_256_KDF = 0x0000000B
+    SHA3_384_KDF = 0x0000000C
+    SHA3_512_KDF = 0x0000000D
 
     def __repr__(self):
-        return '<KDF.%s>' % self.name
+        return "<KDF.%s>" % self.name
 
 
 class MGF(IntEnum):
     """
     RSA PKCS #1 Mask Generation Functions.
     """
+
     SHA1 = 0x00000001
     SHA256 = 0x00000002
     SHA384 = 0x00000003
     SHA512 = 0x00000004
     SHA224 = 0x00000005
+    SHA3_224 = 0x00000006
+    SHA3_256 = 0x00000007
+    SHA3_384 = 0x00000008
+    SHA3_512 = 0x00000009
 
     def __repr__(self):
-        return '<MGF.%s>' % self.name
+        return "<MGF.%s>" % self.name
